@@ -2,4 +2,4 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from fir3base.v1.classes.firebase import FireBase
\ No newline at end of file
+from fir3base.v1.classes.firebase import Firebase
\ No newline at end of file
