@@ -6,11 +6,11 @@ from fir3base.v1.classes.config import *
 
 # the firebase class.
 class Firebase(object):
-	def __init__(self, credentials=None):
+	def __init__(self, key=None):
 		
 		# initialize firestore.
 		# (in classes.config)
-		cred = _credentials_.Certificate(credentials) # must still be edited through env variables.
+		cred = credentials.Certificate(key) # must still be edited through env variables.
 		firebase_admin.initialize_app(cred)
 		self.db = firestore.client()
 
@@ -68,6 +68,3 @@ class Firebase(object):
 					doc = doc.collection(r)
 					c = 1
 		return doc
-
-# initialized objects.
-firebase = Firebase()
